==> nmh-0.06.tar.gz: nmh-0.06/zotnet/mts/mts.h <==

/*
 * mts.h -- definitions for the mail system
 *
 * $Id$
 */

/*
 * Local and UUCP Host Name
 */
char *LocalName(void);
char *SystemName(void);
char *UucpChan(void);

/*
 * Mailboxes
 */
extern char *mmdfldir;
extern char *mmdflfil;
extern char *uucpldir;
extern char *uucplfil;

#define	MAILDIR	(mmdfldir && *mmdfldir ? mmdfldir : getenv ("HOME"))
#define	MAILFIL	(mmdflfil && *mmdflfil ? mmdflfil : getusr ())
#define	UUCPDIR	(uucpldir && *uucpldir ? uucpldir : getenv ("HOME"))
#define	UUCPFIL	(uucplfil && *uucplfil ? uucplfil : getusr ())

char *getusr(void);
char *getfullname(void);

/*
 * Separators
 */
extern char *mmdlm1;
extern char *mmdlm2;

#define	isdlm1(s) (strcmp (s, mmdlm1) == 0)
#define	isdlm2(s) (strcmp (s, mmdlm2) == 0)

/*
 * Filters
 */
extern char *umincproc;

/*
 * Locking Directory
 */
#define	LOK_UNIX 0
#define	LOK_BELL 1
#define	LOK_MMDF 2

#ifndef	MMDFONLY
extern int lockstyle;
#endif /* MMDFONLY */

extern char *lockldir;

/*
 * locking prototypes
 */
int lkopen(char *, int);
int lkclose(int, char*);
FILE *lkfopen(char *, char *);
int lkfclose(FILE *, char *);

/*
 * MTS specific variables
 */
#ifdef MHMTS
extern char *Mailqdir;
extern char *TMailqdir;
extern int Syscpy;
extern char *Overseer;
extern char *Mailer;
extern char *Fromtmp;
extern char *Msgtmp;
extern char *Errtmp;
extern int Tmpmode;
extern char *Okhosts;
extern char *Okdests;
#endif /* MHMTS */

#ifdef MMDFMTS
#endif /* MMDFMTS */

#ifdef SENDMTS
extern char *hostable;
extern char *sendmail;
#endif /* SENDMTS */

/*
 * SMTP/POP stuff
 */
extern char *clientname;
extern char *servers;
extern char *pophost;

/*
 * BBoards-specific variables
 */
extern char *bb_domain;

/*
 * POP BBoards-specific variables
 */
#ifdef BPOP
extern char *popbbhost;
extern char *popbbuser;
extern char *popbblist;
#endif /* BPOP */

/*
 * MailDelivery
 */
extern char *maildelivery;

/*
 * Aliasing Facility (doesn't belong here)
 */
extern int Everyone;
extern char *NoShell;

==> nmh-0.15.tar.gz: nmh-0.15/zotnet/mts/mts.h <==

/*
 * mts.h -- definitions for the mail system
 *
 * $Id$
 */

/*
 * Local and UUCP Host Name
 */
char *LocalName(void);
char *SystemName(void);
char *UucpChan(void);

/*
 * Mailboxes
 */
extern char *mmdfldir;
extern char *mmdflfil;
extern char *uucpldir;
extern char *uucplfil;

#define	MAILDIR	(mmdfldir && *mmdfldir ? mmdfldir : getenv ("HOME"))
#define	MAILFIL	(mmdflfil && *mmdflfil ? mmdflfil : getusr ())
#define	UUCPDIR	(uucpldir && *uucpldir ? uucpldir : getenv ("HOME"))
#define	UUCPFIL	(uucplfil && *uucplfil ? uucplfil : getusr ())

char *getusr(void);
char *getfullname(void);

/*
 * Separators
 */
extern char *mmdlm1;
extern char *mmdlm2;

#define	isdlm1(s) (strcmp (s, mmdlm1) == 0)
#define	isdlm2(s) (strcmp (s, mmdlm2) == 0)

/*
 * Filters
 */
extern char *umincproc;

/*
 * Read mts.conf file
 */
void mts_init (char *);

/*
 * locking prototypes
 */
int lkopen(char *, int);
int lkclose(int, char*);
FILE *lkfopen(char *, char *);
int lkfclose(FILE *, char *);

/*
 * MTS specific variables
 */
#ifdef MHMTS
extern char *Mailqdir;
extern char *TMailqdir;
extern int Syscpy;
extern char *Overseer;
extern char *Mailer;
extern char *Fromtmp;
extern char *Msgtmp;
extern char *Errtmp;
extern int Tmpmode;
extern char *Okhosts;
extern char *Okdests;
#endif /* MHMTS */

#ifdef MMDFMTS
#endif /* MMDFMTS */

#ifdef SENDMTS
extern char *hostable;
extern char *sendmail;
#endif /* SENDMTS */

/*
 * SMTP/POP stuff
 */
extern char *clientname;
extern char *servers;
extern char *pophost;

/*
 * BBoards-specific variables
 */
extern char *bb_domain;

/*
 * POP BBoards-specific variables
 */
#ifdef BPOP
extern char *popbbhost;
extern char *popbbuser;
extern char *popbblist;
#endif /* BPOP */

/*
 * Global MailDelivery File
 */
extern char *maildelivery;

/*
 * Aliasing Facility (doesn't belong here)
 */
extern int Everyone;
extern char *NoShell;
